telutils/phoneparser/src/CPhoneGsmMiscHandler.cpp
branchRCL_3
changeset 20 987c9837762f
parent 19 7d48bed6ce0c
--- a/telutils/phoneparser/src/CPhoneGsmMiscHandler.cpp	Tue Aug 31 15:45:17 2010 +0300
+++ b/telutils/phoneparser/src/CPhoneGsmMiscHandler.cpp	Wed Sep 01 12:15:03 2010 +0100
@@ -11,15 +11,15 @@
 *
 * Contributors:
 *
 * Description:  Implementation of handler for USSD.
 *
 */
 
 
 // INCLUDE FILES
-#include    "cphonegsmmischandler.h" 
-#include    "cphonegsmparserbase.h" 
-#include    "cphonegsmparserresult.h" 
+#include    "CPhoneGsmMiscHandler.h"
+#include    "CPhoneGsmParserBase.h"
+#include    "CPhoneGsmParserResult.h"
 
 // ============================ MEMBER FUNCTIONS ===============================
 
@@ -42,6 +42,10 @@
                 }
             break;
 
+        case KPhoneUidIMEI:
+            ProcessShowIMEIL();
+            break;
+
         default:
             break;
         }
@@ -11,15 +11,15 @@
 * Contributors:
 *
-* Description:  Implementation of handler for USSD.
+* Description:  Implementation of handlers for USSD and IMEI.
 *
 */